@@ -21,19 +21,21 @@ using namespace mrpt::gui;
 
 class CMyGLCanvas : public CWxGLCanvasBase
 {
-   public:
-	CMyGLCanvas(
-		wxWindow* parent, wxWindowID id = wxID_ANY,
-		const wxPoint& pos = wxDefaultPosition,
-		const wxSize& size = wxDefaultSize, long style = 0,
-		const wxString& name = _T("CMyGLCanvas"));
+ public:
+  CMyGLCanvas(
+      wxWindow* parent,
+      wxWindowID id = wxID_ANY,
+      const wxPoint& pos = wxDefaultPosition,
+      const wxSize& size = wxDefaultSize,
+      long style = 0,
+      const wxString& name = _T("CMyGLCanvas"));
 
-	~CMyGLCanvas() override;
+  ~CMyGLCanvas() override;
 
-	void OnPreRender() override;
-	void OnPostRender() override;
-	void OnPostRenderSwapBuffers(double At, wxPaintDC& dc) override;
-	void OnRenderError(const wxString& str) override;
+  void OnPreRender() override;
+  void OnPostRender() override;
+  void OnPostRenderSwapBuffers(double At, wxPaintDC& dc) override;
+  void OnRenderError(const wxString& str) override;
 };
 
 #else
@@ -41,16 +43,18 @@ class CMyGLCanvas : public CWxGLCanvasBase
 // Dummy class
 class CMyGLCanvas : public wxPanel
 {
-   public:
-	CMyGLCanvas(
-		wxWindow* parent, wxWindowID id = wxID_ANY,
-		const wxPoint& pos = wxDefaultPosition,
-		const wxSize& size = wxDefaultSize, long style = 0,
-		const wxString& name = _T("CMyGLCanvas"))
-	{
-	}
+ public:
+  CMyGLCanvas(
+      wxWindow* parent,
+      wxWindowID id = wxID_ANY,
+      const wxPoint& pos = wxDefaultPosition,
+      const wxSize& size = wxDefaultSize,
+      long style = 0,
+      const wxString& name = _T("CMyGLCanvas"))
+  {
+  }
 };
 
-#endif	// Have glut
+#endif  // Have glut
 
-#endif	// MYGLCANVAS_H
+#endif  // MYGLCANVAS_H
