@@ -14,15 +14,19 @@ using namespace std;
 #if APP_HAS_3D
 
 CMyGLCanvas::CMyGLCanvas(
-	wxWindow* parent, wxWindowID id, const wxPoint& pos, const wxSize& size,
-	long style, const wxString& name)
-	: CWxGLCanvasBase(parent, id, pos, size, style, name)
+    wxWindow* parent,
+    wxWindowID id,
+    const wxPoint& pos,
+    const wxSize& size,
+    long style,
+    const wxString& name) :
+    CWxGLCanvasBase(parent, id, pos, size, style, name)
 {
-	setCameraPointing(0.0f, 0.0f, 0.0f);
-	setZoomDistance(20.0f);
-	setElevationDegrees(45.0f);
-	setAzimuthDegrees(135.0f);
-	setCameraProjective(true);
+  setCameraPointing(0.0f, 0.0f, 0.0f);
+  setZoomDistance(20.0f);
+  setElevationDegrees(45.0f);
+  setAzimuthDegrees(135.0f);
+  setCameraProjective(true);
 }
 
 CMyGLCanvas::~CMyGLCanvas() = default;
