@@ -18,17 +18,18 @@ class CBaseObservationNode;
 
 class CObservationsNode : public CNode
 {
-   public:
-	CObservationsNode(
-		CNode* parent, const mrpt::obs::CSensoryFrame::Ptr& sensoryFrame,
-		const mrpt::poses::CPose3D& pose);
-	~CObservationsNode() override;
-	// CNode interface
-	int childCount() const override;
-	CNode* child(int id) override;
-	ObjectType type() const override;
-	std::string displayName() const override;
+ public:
+  CObservationsNode(
+      CNode* parent,
+      const mrpt::obs::CSensoryFrame::Ptr& sensoryFrame,
+      const mrpt::poses::CPose3D& pose);
+  ~CObservationsNode() override;
+  // CNode interface
+  int childCount() const override;
+  CNode* child(int id) override;
+  ObjectType type() const override;
+  std::string displayName() const override;
 
-   private:
-	std::vector<std::unique_ptr<CBaseObservationNode>> m_observations;
+ private:
+  std::vector<std::unique_ptr<CBaseObservationNode>> m_observations;
 };
