@@ -7,7 +7,7 @@
    | Released under BSD License. See: https://www.mrpt.org/License          |
    +------------------------------------------------------------------------+ */
 
-#include "containers-precomp.h"	 // Precompiled headers
+#include "containers-precomp.h"  // Precompiled headers
 //
 #include <mrpt/containers/CDynamicGrid.h>
 #include <mrpt/core/format.h>
@@ -15,17 +15,16 @@
 #include <fstream>
 
 bool mrpt::containers::internal::dynamic_grid_txt_saver::saveToTextFile(
-	const std::string& fileName) const
+    const std::string& fileName) const
 {
-	std::ofstream f;
-	f.open(fileName.c_str(), std::ofstream::out);
-	if (!f.is_open()) return false;
-	const unsigned int sy = getSizeY(), sx = getSizeX();
-	for (unsigned int cy = 0; cy < sy; cy++)
-	{
-		for (unsigned int cx = 0; cx < sx; cx++)
-			f << mrpt::format("%f ", getCellAsFloat(cx, cy));
-		f << "\n";
-	}
-	return true;
+  std::ofstream f;
+  f.open(fileName.c_str(), std::ofstream::out);
+  if (!f.is_open()) return false;
+  const unsigned int sy = getSizeY(), sx = getSizeX();
+  for (unsigned int cy = 0; cy < sy; cy++)
+  {
+    for (unsigned int cx = 0; cx < sx; cx++) f << mrpt::format("%f ", getCellAsFloat(cx, cy));
+    f << "\n";
+  }
+  return true;
 }
