@@ -13,8 +13,6 @@
 #define SELBYTE2(v) ((v >> 16) & 0xff)
 #define SELBYTE3(v) ((v >> 24) & 0xff)
 
-#define MAKEWORD16B(__LOBYTE, __HILOBYTE) ((__LOBYTE) | ((__HILOBYTE) << 8))
-#define MAKEWORD32B(__LOWORD16, __HIWORD16)                                    \
-	((__LOWORD16) | ((__HIWORD16) << 16))
-#define MAKEWORD64B(__LOWORD32, __HIWORD32)                                    \
-	((__LOWORD32) | ((__HIWORD32) << 32))
+#define MAKEWORD16B(__LOBYTE, __HILOBYTE)   ((__LOBYTE) | ((__HILOBYTE) << 8))
+#define MAKEWORD32B(__LOWORD16, __HIWORD16) ((__LOWORD16) | ((__HIWORD16) << 16))
+#define MAKEWORD64B(__LOWORD32, __HIWORD32) ((__LOWORD32) | ((__HIWORD32) << 32))
