@@ -7,43 +7,36 @@
    | Released under BSD License. See: https://www.mrpt.org/License          |
    +------------------------------------------------------------------------+ */
 
-#include "io-precomp.h"	 // Precompiled headers
+#include "io-precomp.h"  // Precompiled headers
 //
 #include <mrpt/core/exceptions.h>
 #include <mrpt/io/lazy_load_path.h>
 
 static std::string LAZY_LOAD_PATH_BASE(".");
 
-std::string mrpt::io::lazy_load_absolute_path(
-	const std::string& relativeOrAbsolutePath)
+std::string mrpt::io::lazy_load_absolute_path(const std::string& relativeOrAbsolutePath)
 {
-	const auto& fil = relativeOrAbsolutePath;
+  const auto& fil = relativeOrAbsolutePath;
 
-	ASSERT_(fil.size() > 2);
+  ASSERT_(fil.size() > 2);
 
-	if (fil[0] == '/' || (fil[1] == ':' && (fil[2] == '\\' || fil[2] == '/')))
-	{  // already absolute:
-		return fil;
-	}
+  if (fil[0] == '/' || (fil[1] == ':' && (fil[2] == '\\' || fil[2] == '/')))
+  {  // already absolute:
+    return fil;
+  }
 
-	// It is relative:
-	auto out_path = LAZY_LOAD_PATH_BASE;
-	ASSERT_(!LAZY_LOAD_PATH_BASE.empty());
+  // It is relative:
+  auto out_path = LAZY_LOAD_PATH_BASE;
+  ASSERT_(!LAZY_LOAD_PATH_BASE.empty());
 
-	const auto lastChar = *LAZY_LOAD_PATH_BASE.rbegin();
+  const auto lastChar = *LAZY_LOAD_PATH_BASE.rbegin();
 
-	if (lastChar != '/' && lastChar != '\\') out_path += "/";
+  if (lastChar != '/' && lastChar != '\\') out_path += "/";
 
-	out_path += fil;
-	return out_path;
+  out_path += fil;
+  return out_path;
 }
 
-const std::string& mrpt::io::getLazyLoadPathBase()
-{
-	return LAZY_LOAD_PATH_BASE;
-}
+const std::string& mrpt::io::getLazyLoadPathBase() { return LAZY_LOAD_PATH_BASE; }
 
-void mrpt::io::setLazyLoadPathBase(const std::string& path)
-{
-	LAZY_LOAD_PATH_BASE = path;
-}
+void mrpt::io::setLazyLoadPathBase(const std::string& path) { LAZY_LOAD_PATH_BASE = path; }
