@@ -13,16 +13,15 @@
 
 #include "CMatrixFixed_impl.h"
 
-#define DO_VECFIXED_INSTANTIATION_NM(T_, N_)                                   \
-	template class mrpt::math::CMatrixFixed<T_, N_, 1>;
+#define DO_VECFIXED_INSTANTIATION_NM(T_, N_) template class mrpt::math::CMatrixFixed<T_, N_, 1>;
 
-#define DO_VECFIXED_INSTANTIATION(T_)                                          \
-	DO_VECFIXED_INSTANTIATION_NM(T_, 2)                                        \
-	DO_VECFIXED_INSTANTIATION_NM(T_, 3)                                        \
-	DO_VECFIXED_INSTANTIATION_NM(T_, 4)                                        \
-	DO_VECFIXED_INSTANTIATION_NM(T_, 5)                                        \
-	DO_VECFIXED_INSTANTIATION_NM(T_, 6)                                        \
-	DO_VECFIXED_INSTANTIATION_NM(T_, 7)
+#define DO_VECFIXED_INSTANTIATION(T_) \
+  DO_VECFIXED_INSTANTIATION_NM(T_, 2) \
+  DO_VECFIXED_INSTANTIATION_NM(T_, 3) \
+  DO_VECFIXED_INSTANTIATION_NM(T_, 4) \
+  DO_VECFIXED_INSTANTIATION_NM(T_, 5) \
+  DO_VECFIXED_INSTANTIATION_NM(T_, 6) \
+  DO_VECFIXED_INSTANTIATION_NM(T_, 7)
 
 DO_VECFIXED_INSTANTIATION(float);
 DO_VECFIXED_INSTANTIATION(double);
