@@ -16,9 +16,8 @@
 #include "MatrixBase_impl.h"
 
 // Template instantiations:
-#define DO_MATFIXED_INSTANTIATION_NM(T_, N_, M_)                               \
-	template class mrpt::math::MatrixBase<                                     \
-		T_, mrpt::math::CMatrixFixed<T_, N_, M_>>;
+#define DO_MATFIXED_INSTANTIATION_NM(T_, N_, M_) \
+  template class mrpt::math::MatrixBase<T_, mrpt::math::CMatrixFixed<T_, N_, M_>>;
 
 #define DO_MATFIXED_INSTANTIATION(T_) DO_MATFIXED_INSTANTIATION_NM(T_, 6, 6)
 
