@@ -15,5 +15,4 @@
 using namespace mrpt;
 using namespace mrpt::nav;
 
-IMPLEMENTS_VIRTUAL_SERIALIZABLE(
-	CHolonomicLogFileRecord, CSerializable, mrpt::nav)
+IMPLEMENTS_VIRTUAL_SERIALIZABLE(CHolonomicLogFileRecord, CSerializable, mrpt::nav)
