@@ -19,67 +19,69 @@ using namespace mrpt::poses;
 IMPLEMENTS_SERIALIZABLE(CObservationWindSensor, CObservation, mrpt::obs)
 
 uint8_t CObservationWindSensor::serializeGetVersion() const { return 3; }
-void CObservationWindSensor::serializeTo(
-	mrpt::serialization::CArchive& out) const
+void CObservationWindSensor::serializeTo(mrpt::serialization::CArchive& out) const
 {
-	out << speed << direction << sensorLabel << timestamp << sensorPoseOnRobot;
+  out << speed << direction << sensorLabel << timestamp << sensorPoseOnRobot;
 }
 
-void CObservationWindSensor::serializeFrom(
-	mrpt::serialization::CArchive& in, uint8_t version)
+void CObservationWindSensor::serializeFrom(mrpt::serialization::CArchive& in, uint8_t version)
 {
-	switch (version)
-	{
-		case 0:
-		case 1:
-		case 2:
-		case 3:
-		{
-			in >> speed >> direction;
-			if (version >= 1) in >> sensorLabel;
-			else
-				sensorLabel = "";
+  switch (version)
+  {
+    case 0:
+    case 1:
+    case 2:
+    case 3:
+    {
+      in >> speed >> direction;
+      if (version >= 1)
+        in >> sensorLabel;
+      else
+        sensorLabel = "";
 
-			if (version >= 2) in >> timestamp;
-			else
-				timestamp = INVALID_TIMESTAMP;
+      if (version >= 2)
+        in >> timestamp;
+      else
+        timestamp = INVALID_TIMESTAMP;
 
-			if (version >= 3) in >> sensorPoseOnRobot;
-			else
-				sensorPoseOnRobot = CPose3D();
-		}
-		break;
-		default: MRPT_THROW_UNKNOWN_SERIALIZATION_VERSION(version);
-	};
+      if (version >= 3)
+        in >> sensorPoseOnRobot;
+      else
+        sensorPoseOnRobot = CPose3D();
+    }
+    break;
+    default:
+      MRPT_THROW_UNKNOWN_SERIALIZATION_VERSION(version);
+  };
 }
 
 void CObservationWindSensor::getSensorPose(CPose3D& out_sensorPose) const
 {
-	out_sensorPose = sensorPoseOnRobot;
+  out_sensorPose = sensorPoseOnRobot;
 }
 
 void CObservationWindSensor::setSensorPose(const CPose3D& newSensorPose)
 {
-	sensorPoseOnRobot = newSensorPose;
+  sensorPoseOnRobot = newSensorPose;
 }
 
 void CObservationWindSensor::getDescriptionAsText(std::ostream& o) const
 {
-	CObservation::getDescriptionAsText(o);
+  CObservation::getDescriptionAsText(o);
 }
 
 std::string CObservationWindSensor::exportTxtHeader() const
 {
-	return mrpt::format(
-		"%18s %18s"	 // WIND (mod, direction)
-		,
-		"WIND_MODULE(m/s)", "WIND_DIRECTION (deg)");
+  return mrpt::format(
+      "%18s %18s"  // WIND (mod, direction)
+      ,
+      "WIND_MODULE(m/s)", "WIND_DIRECTION (deg)");
 }
 
 std::string CObservationWindSensor::exportTxtDataRow() const
 {
-	return mrpt::format(
-		"%18.5f %18.3f"	 // WIND (mod, direction)
-		,
-		speed, direction);
+  return mrpt::format(
+      "%18.5f %18.3f"  // WIND (mod, direction)
+      ,
+      speed, direction);
 }
