@@ -35,16 +35,17 @@ void CRenderizableShaderTexturedTriangles::renderUpdateBuffers() const
   const_cast<CRenderizableShaderTexturedTriangles&>(*this).onUpdateBuffers_TexturedTriangles();
 
   std::shared_lock<std::shared_mutex> readLock(m_trianglesMtx.data);
+  auto gh = gls();
 
   const auto n = m_triangles.size();
 
   // Define OpenGL buffers:
-  (*m_vbo)->createOnce();
-  (*m_vbo)->bind();
-  (*m_vbo)->allocate(m_triangles.data(), sizeof(m_triangles[0]) * n);
+  gh.state.vbo->createOnce();
+  gh.state.vbo->bind();
+  gh.state.vbo->allocate(m_triangles.data(), sizeof(m_triangles[0]) * n);
 
   // VAO: required to use glEnableVertexAttribArray()
-  (*m_vao)->createOnce();
+  gh.state.vao->createOnce();
 
 #endif
 }
@@ -58,6 +59,7 @@ void CRenderizableShaderTexturedTriangles::render(const RenderContext& rc) const
   ASSERT_(m_glTexture.initialized());
 
   std::shared_lock<std::shared_mutex> readLock(m_trianglesMtx.data);
+  auto gh = gls();
 
   // Set the texture uniform:
   const Program& s = *rc.shader;
@@ -113,9 +115,9 @@ void CRenderizableShaderTexturedTriangles::render(const RenderContext& rc) const
   if (rc.shader->hasAttribute("position"))
   {
     attr_position = rc.shader->attributeId("position");
-    (*m_vao)->bind();
+    gh.state.vao->bind();
     glEnableVertexAttribArray(*attr_position);
-    (*m_vbo)->bind();
+    gh.state.vbo->bind();
     glVertexAttribPointer(
         *attr_position,            /* attribute */
         3,                         /* size */
@@ -132,7 +134,7 @@ void CRenderizableShaderTexturedTriangles::render(const RenderContext& rc) const
   {
     attr_normals = rc.shader->attributeId("vertexNormal");
     glEnableVertexAttribArray(*attr_normals);
-    (*m_vbo)->bind();
+    gh.state.vbo->bind();
     glVertexAttribPointer(
         *attr_normals,             /* attribute */
         3,                         /* size */
@@ -149,7 +151,7 @@ void CRenderizableShaderTexturedTriangles::render(const RenderContext& rc) const
   {
     attr_uv = rc.shader->attributeId("vertexUV");
     glEnableVertexAttribArray(*attr_uv);
-    (*m_vbo)->bind();
+    gh.state.vbo->bind();
     glVertexAttribPointer(
         *attr_uv,                  /* attribute */
         2,                         /* size */
