@@ -28,25 +28,24 @@ void CRenderizableShaderWireFrame::renderUpdateBuffers() const
   // Generate vertices & colors:
   const_cast<CRenderizableShaderWireFrame&>(*this).onUpdateBuffers_Wireframe();
 
-  std::shared_lock<std::shared_mutex> wfReadLock(CRenderizableShaderWireFrame::m_wireframeMtx.data);
+  const std::shared_lock<std::shared_mutex> wfReadLock(
+      CRenderizableShaderWireFrame::m_wireframeMtx.data);
+  auto gh = gls();
 
   // Define OpenGL buffers:
-  (*m_vertexBuffer)->createOnce();
-  (*m_vertexBuffer)->bind();
-  (*m_vertexBuffer)
-      ->allocate(
-          m_vertex_buffer_data.data(),
-          sizeof(m_vertex_buffer_data[0]) * m_vertex_buffer_data.size());
+  gh.state.vertexBuffer->createOnce();
+  gh.state.vertexBuffer->bind();
+  gh.state.vertexBuffer->allocate(
+      m_vertex_buffer_data.data(), sizeof(m_vertex_buffer_data[0]) * m_vertex_buffer_data.size());
 
   // color buffer:
-  (*m_colorBuffer)->createOnce();
-  (*m_colorBuffer)->bind();
-  (*m_colorBuffer)
-      ->allocate(
-          m_color_buffer_data.data(), sizeof(m_color_buffer_data[0]) * m_color_buffer_data.size());
+  gh.state.colorBuffer->createOnce();
+  gh.state.colorBuffer->bind();
+  gh.state.colorBuffer->allocate(
+      m_color_buffer_data.data(), sizeof(m_color_buffer_data[0]) * m_color_buffer_data.size());
 
   // VAO: required to use glEnableVertexAttribArray()
-  (*m_vao)->createOnce();
+  gh.state.vao->createOnce();
 #endif
 }
 
@@ -59,16 +58,18 @@ void CRenderizableShaderWireFrame::render(const RenderContext& rc) const
   // Skip these geometric entities when in the 1st pass of shadow map:
   if (rc.state->is1stShadowMapPass) return;
 
-  std::shared_lock<std::shared_mutex> wfReadLock(CRenderizableShaderWireFrame::m_wireframeMtx.data);
+  const std::shared_lock<std::shared_mutex> wfReadLock(
+      CRenderizableShaderWireFrame::m_wireframeMtx.data);
+  auto gh = gls();
 
   // Set up the vertex array:
   std::optional<GLuint> attr_position;
   if (rc.shader->hasAttribute("position"))
   {
     attr_position = rc.shader->attributeId("position");
-    (*m_vao)->bind();
+    gh.state.vao->bind();
     glEnableVertexAttribArray(*attr_position);
-    (*m_vertexBuffer)->bind();
+    gh.state.vertexBuffer->bind();
     glVertexAttribPointer(
         *attr_position,  /* attribute */
         3,               /* size */
@@ -86,7 +87,7 @@ void CRenderizableShaderWireFrame::render(const RenderContext& rc) const
   {
     attr_color = rc.shader->attributeId("vertexColor");
     glEnableVertexAttribArray(*attr_color);
-    (*m_colorBuffer)->bind();
+    gh.state.colorBuffer->bind();
     glVertexAttribPointer(
         *attr_color,      /* attribute */
         4,                /* size */
