@@ -44,9 +44,10 @@ namespace mrpt::poses
  * \sa CPoseOrPoint
  * \ingroup interpolation_grp poses_grp
  */
-class CPose3DInterpolator : public mrpt::serialization::CSerializable,
-							public mrpt::poses::CPoseInterpolatorBase<3>
+class CPose3DInterpolator :
+    public mrpt::serialization::CSerializable,
+    public mrpt::poses::CPoseInterpolatorBase<3>
 {
-	DEFINE_SERIALIZABLE(CPose3DInterpolator, mrpt::poses)
-};	// End of class def.
+  DEFINE_SERIALIZABLE(CPose3DInterpolator, mrpt::poses)
+};  // End of class def.
 }  // namespace mrpt::poses
