@@ -7,7 +7,7 @@
    | Released under BSD License. See: https://www.mrpt.org/License          |
    +------------------------------------------------------------------------+ */
 
-#include "vision-precomp.h"	 // Precompiled headers
+#include "vision-precomp.h"  // Precompiled headers
 //
 #include <mrpt/obs/CObservationVisualLandmarks.h>
 #include <mrpt/serialization/CArchive.h>
@@ -20,41 +20,38 @@ IMPLEMENTS_SERIALIZABLE(CObservationVisualLandmarks, CObservation, mrpt::obs)
 
 /** Constructor
  */
-CObservationVisualLandmarks::CObservationVisualLandmarks()
-	: refCameraPose(), landmarks()
-{
-}
+CObservationVisualLandmarks::CObservationVisualLandmarks() : refCameraPose(), landmarks() {}
 
 uint8_t CObservationVisualLandmarks::serializeGetVersion() const { return 1; }
-void CObservationVisualLandmarks::serializeTo(
-	mrpt::serialization::CArchive& out) const
+void CObservationVisualLandmarks::serializeTo(mrpt::serialization::CArchive& out) const
 {
-	out << refCameraPose
-		<< timestamp
-		// The landmarks:
-		<< landmarks << sensorLabel;
+  out << refCameraPose
+      << timestamp
+      // The landmarks:
+      << landmarks << sensorLabel;
 }
 
-void CObservationVisualLandmarks::serializeFrom(
-	mrpt::serialization::CArchive& in, uint8_t version)
+void CObservationVisualLandmarks::serializeFrom(mrpt::serialization::CArchive& in, uint8_t version)
 {
-	switch (version)
-	{
-		case 0:
-		case 1:
-		{
-			in >> refCameraPose >> timestamp
+  switch (version)
+  {
+    case 0:
+    case 1:
+    {
+      in >> refCameraPose >> timestamp
 
-				// The landmarks:
-				>> landmarks;
+          // The landmarks:
+          >> landmarks;
 
-			if (version > 0) in >> sensorLabel;
-			else
-				sensorLabel = "";
-		}
-		break;
-		default: MRPT_THROW_UNKNOWN_SERIALIZATION_VERSION(version);
-	};
+      if (version > 0)
+        in >> sensorLabel;
+      else
+        sensorLabel = "";
+    }
+    break;
+    default:
+      MRPT_THROW_UNKNOWN_SERIALIZATION_VERSION(version);
+  };
 }
 
 /*---------------------------------------------------------------
@@ -72,13 +69,13 @@ void CObservationVisualLandmarks::serializeFrom(
  invalid class.
   ---------------------------------------------------------------*/
 float CObservationVisualLandmarks::likelihoodWith(
-	[[maybe_unused]] const CObservation* anotherObs,
-	[[maybe_unused]] const CPosePDF* anotherObsPose) const
+    [[maybe_unused]] const CObservation* anotherObs,
+    [[maybe_unused]] const CPosePDF* anotherObsPose) const
 {
-	return 0;
+  return 0;
 }
 
 void CObservationVisualLandmarks::getDescriptionAsText(std::ostream& o) const
 {
-	CObservation::getDescriptionAsText(o);
+  CObservation::getDescriptionAsText(o);
 }
