@@ -1,11 +1,4 @@
-#include <any>
-#include <chrono>
-#include <deque>
 #include <functional>
-#include <ios>
-#include <istream>
-#include <iterator>
-#include <map>
 #include <memory>
 #include <mrpt/bayes/CKalmanFilterCapable.h>
 #include <mrpt/config/CConfigFileBase.h>
@@ -66,23 +59,10 @@
 #include <mrpt/poses/CPosePDFGaussian.h>
 #include <mrpt/rtti/CObject.h>
 #include <mrpt/serialization/CArchive.h>
-#include <mrpt/serialization/CMessage.h>
 #include <mrpt/serialization/CSerializable.h>
 #include <mrpt/system/COutputLogger.h>
 #include <mrpt/tfest/TMatchingPair.h>
 #include <mrpt/typemeta/static_string.h>
-#include <optional>
-#include <ostream>
-#include <ratio>
-#include <sstream> // __str__
-#include <streambuf>
-#include <string>
-#include <string_view>
-#include <type_traits>
-#include <typeinfo>
-#include <utility>
-#include <variant>
-#include <vector>
 
 #include <functional>
 #include <pybind11/pybind11.h>
@@ -256,45 +236,6 @@ struct PyCallBack_mrpt_maps_CPointsMapXYZI : public mrpt::maps::CPointsMapXYZI {
 		}
 		return CPointsMapXYZI::setSize(a0);
 	}
-	void insertPointFast(float a0, float a1, float a2) override {
-		pybind11::gil_scoped_acquire gil;
-		pybind11::function overload = pybind11::get_overload(static_cast<const mrpt::maps::CPointsMapXYZI *>(this), "insertPointFast");
-		if (overload) {
-			auto o = overload.operator()<pybind11::return_value_policy::reference>(a0, a1, a2);
-			if (pybind11::detail::cast_is_temporary_value_reference<void>::value) {
-				static pybind11::detail::override_caster_t<void> caster;
-				return pybind11::detail::cast_ref<void>(std::move(o), caster);
-			}
-			else return pybind11::detail::cast_safe<void>(std::move(o));
-		}
-		return CPointsMapXYZI::insertPointFast(a0, a1, a2);
-	}
-	void impl_copyFrom(const class mrpt::maps::CPointsMap & a0) override {
-		pybind11::gil_scoped_acquire gil;
-		pybind11::function overload = pybind11::get_overload(static_cast<const mrpt::maps::CPointsMapXYZI *>(this), "impl_copyFrom");
-		if (overload) {
-			auto o = overload.operator()<pybind11::return_value_policy::reference>(a0);
-			if (pybind11::detail::cast_is_temporary_value_reference<void>::value) {
-				static pybind11::detail::override_caster_t<void> caster;
-				return pybind11::detail::cast_ref<void>(std::move(o), caster);
-			}
-			else return pybind11::detail::cast_safe<void>(std::move(o));
-		}
-		return CPointsMapXYZI::impl_copyFrom(a0);
-	}
-	void addFrom_classSpecific(const class mrpt::maps::CPointsMap & a0, size_t a1, const bool a2) override {
-		pybind11::gil_scoped_acquire gil;
-		pybind11::function overload = pybind11::get_overload(static_cast<const mrpt::maps::CPointsMapXYZI *>(this), "addFrom_classSpecific");
-		if (overload) {
-			auto o = overload.operator()<pybind11::return_value_policy::reference>(a0, a1, a2);
-			if (pybind11::detail::cast_is_temporary_value_reference<void>::value) {
-				static pybind11::detail::override_caster_t<void> caster;
-				return pybind11::detail::cast_ref<void>(std::move(o), caster);
-			}
-			else return pybind11::detail::cast_safe<void>(std::move(o));
-		}
-		return CPointsMapXYZI::addFrom_classSpecific(a0, a1, a2);
-	}
 	void setPointRGB(size_t a0, float a1, float a2, float a3, float a4, float a5, float a6) override {
 		pybind11::gil_scoped_acquire gil;
 		pybind11::function overload = pybind11::get_overload(static_cast<const mrpt::maps::CPointsMapXYZI *>(this), "setPointRGB");
@@ -360,19 +301,6 @@ struct PyCallBack_mrpt_maps_CPointsMapXYZI : public mrpt::maps::CPointsMapXYZI {
 		}
 		return CPointsMapXYZI::getVisualizationInto(a0);
 	}
-	void insertPointField_Intensity(float a0) override {
-		pybind11::gil_scoped_acquire gil;
-		pybind11::function overload = pybind11::get_overload(static_cast<const mrpt::maps::CPointsMapXYZI *>(this), "insertPointField_Intensity");
-		if (overload) {
-			auto o = overload.operator()<pybind11::return_value_policy::reference>(a0);
-			if (pybind11::detail::cast_is_temporary_value_reference<void>::value) {
-				static pybind11::detail::override_caster_t<void> caster;
-				return pybind11::detail::cast_ref<void>(std::move(o), caster);
-			}
-			else return pybind11::detail::cast_safe<void>(std::move(o));
-		}
-		return CPointsMapXYZI::insertPointField_Intensity(a0);
-	}
 	void saveMetricMapRepresentationToFile(const std::string & a0) const override {
 		pybind11::gil_scoped_acquire gil;
 		pybind11::function overload = pybind11::get_overload(static_cast<const mrpt::maps::CPointsMapXYZI *>(this), "saveMetricMapRepresentationToFile");
@@ -477,84 +405,19 @@ struct PyCallBack_mrpt_maps_CPointsMapXYZI : public mrpt::maps::CPointsMapXYZI {
 		}
 		return CPointsMap::setPointWeight(a0, a1);
 	}
-	unsigned int getPointWeight(size_t a0) const override {
+	unsigned long getPointWeight(size_t a0) const override {
 		pybind11::gil_scoped_acquire gil;
 		pybind11::function overload = pybind11::get_overload(static_cast<const mrpt::maps::CPointsMapXYZI *>(this), "getPointWeight");
 		if (overload) {
 			auto o = overload.operator()<pybind11::return_value_policy::reference>(a0);
-			if (pybind11::detail::cast_is_temporary_value_reference<unsigned int>::value) {
-				static pybind11::detail::override_caster_t<unsigned int> caster;
-				return pybind11::detail::cast_ref<unsigned int>(std::move(o), caster);
+			if (pybind11::detail::cast_is_temporary_value_reference<unsigned long>::value) {
+				static pybind11::detail::override_caster_t<unsigned long> caster;
+				return pybind11::detail::cast_ref<unsigned long>(std::move(o), caster);
 			}
-			else return pybind11::detail::cast_safe<unsigned int>(std::move(o));
+			else return pybind11::detail::cast_safe<unsigned long>(std::move(o));
 		}
 		return CPointsMap::getPointWeight(a0);
 	}
-	void insertPointField_Ring(uint16_t a0) override {
-		pybind11::gil_scoped_acquire gil;
-		pybind11::function overload = pybind11::get_overload(static_cast<const mrpt::maps::CPointsMapXYZI *>(this), "insertPointField_Ring");
-		if (overload) {
-			auto o = overload.operator()<pybind11::return_value_policy::reference>(a0);
-			if (pybind11::detail::cast_is_temporary_value_reference<void>::value) {
-				static pybind11::detail::override_caster_t<void> caster;
-				return pybind11::detail::cast_ref<void>(std::move(o), caster);
-			}
-			else return pybind11::detail::cast_safe<void>(std::move(o));
-		}
-		return CPointsMap::insertPointField_Ring(a0);
-	}
-	void insertPointField_Timestamp(float a0) override {
-		pybind11::gil_scoped_acquire gil;
-		pybind11::function overload = pybind11::get_overload(static_cast<const mrpt::maps::CPointsMapXYZI *>(this), "insertPointField_Timestamp");
-		if (overload) {
-			auto o = overload.operator()<pybind11::return_value_policy::reference>(a0);
-			if (pybind11::detail::cast_is_temporary_value_reference<void>::value) {
-				static pybind11::detail::override_caster_t<void> caster;
-				return pybind11::detail::cast_ref<void>(std::move(o), caster);
-			}
-			else return pybind11::detail::cast_safe<void>(std::move(o));
-		}
-		return CPointsMap::insertPointField_Timestamp(a0);
-	}
-	void insertPointField_color_R(float a0) override {
-		pybind11::gil_scoped_acquire gil;
-		pybind11::function overload = pybind11::get_overload(static_cast<const mrpt::maps::CPointsMapXYZI *>(this), "insertPointField_color_R");
-		if (overload) {
-			auto o = overload.operator()<pybind11::return_value_policy::reference>(a0);
-			if (pybind11::detail::cast_is_temporary_value_reference<void>::value) {
-				static pybind11::detail::override_caster_t<void> caster;
-				return pybind11::detail::cast_ref<void>(std::move(o), caster);
-			}
-			else return pybind11::detail::cast_safe<void>(std::move(o));
-		}
-		return CPointsMap::insertPointField_color_R(a0);
-	}
-	void insertPointField_color_G(float a0) override {
-		pybind11::gil_scoped_acquire gil;
-		pybind11::function overload = pybind11::get_overload(static_cast<const mrpt::maps::CPointsMapXYZI *>(this), "insertPointField_color_G");
-		if (overload) {
-			auto o = overload.operator()<pybind11::return_value_policy::reference>(a0);
-			if (pybind11::detail::cast_is_temporary_value_reference<void>::value) {
-				static pybind11::detail::override_caster_t<void> caster;
-				return pybind11::detail::cast_ref<void>(std::move(o), caster);
-			}
-			else return pybind11::detail::cast_safe<void>(std::move(o));
-		}
-		return CPointsMap::insertPointField_color_G(a0);
-	}
-	void insertPointField_color_B(float a0) override {
-		pybind11::gil_scoped_acquire gil;
-		pybind11::function overload = pybind11::get_overload(static_cast<const mrpt::maps::CPointsMapXYZI *>(this), "insertPointField_color_B");
-		if (overload) {
-			auto o = overload.operator()<pybind11::return_value_policy::reference>(a0);
-			if (pybind11::detail::cast_is_temporary_value_reference<void>::value) {
-				static pybind11::detail::override_caster_t<void> caster;
-				return pybind11::detail::cast_ref<void>(std::move(o), caster);
-			}
-			else return pybind11::detail::cast_safe<void>(std::move(o));
-		}
-		return CPointsMap::insertPointField_color_B(a0);
-	}
 	void determineMatching2D(const class mrpt::maps::CMetricMap * a0, const class mrpt::poses::CPose2D & a1, class mrpt::tfest::TMatchingPairListTempl<float> & a2, const struct mrpt::maps::TMatchingParams & a3, struct mrpt::maps::TMatchingExtraResults & a4) const override {
 		pybind11::gil_scoped_acquire gil;
 		pybind11::function overload = pybind11::get_overload(static_cast<const mrpt::maps::CPointsMapXYZI *>(this), "determineMatching2D");
@@ -791,7 +654,7 @@ struct PyCallBack_mrpt_maps_CPointsMapXYZI : public mrpt::maps::CPointsMapXYZI {
 	}
 };
 
-// mrpt::maps::CPointsMapXYZI::TMapDefinition file: line:85
+// mrpt::maps::CPointsMapXYZI::TMapDefinition file: line:78
 struct PyCallBack_mrpt_maps_CPointsMapXYZI_TMapDefinition : public mrpt::maps::CPointsMapXYZI::TMapDefinition {
 	using mrpt::maps::CPointsMapXYZI::TMapDefinition::TMapDefinition;
 
@@ -878,33 +741,30 @@ void bind_mrpt_maps_CPointCloudFilterByDistance(std::function< pybind11::module
 		cl.def_static("CreateObject", (class std::shared_ptr<class mrpt::rtti::CObject> (*)()) &mrpt::maps::CPointsMapXYZI::CreateObject, "C++: mrpt::maps::CPointsMapXYZI::CreateObject() --> class std::shared_ptr<class mrpt::rtti::CObject>");
 		cl.def("assign", (class mrpt::maps::CPointsMapXYZI & (mrpt::maps::CPointsMapXYZI::*)(const class mrpt::maps::CPointsMap &)) &mrpt::maps::CPointsMapXYZI::operator=, "C++: mrpt::maps::CPointsMapXYZI::operator=(const class mrpt::maps::CPointsMap &) --> class mrpt::maps::CPointsMapXYZI &", pybind11::return_value_policy::automatic, pybind11::arg("o"));
 		cl.def("assign", (class mrpt::maps::CPointsMapXYZI & (mrpt::maps::CPointsMapXYZI::*)(const class mrpt::maps::CPointsMapXYZI &)) &mrpt::maps::CPointsMapXYZI::operator=, "C++: mrpt::maps::CPointsMapXYZI::operator=(const class mrpt::maps::CPointsMapXYZI &) --> class mrpt::maps::CPointsMapXYZI &", pybind11::return_value_policy::automatic, pybind11::arg("o"));
-		cl.def("reserve", (void (mrpt::maps::CPointsMapXYZI::*)(size_t)) &mrpt::maps::CPointsMapXYZI::reserve, "from CPointsMap\n	@{ \n\nC++: mrpt::maps::CPointsMapXYZI::reserve(size_t) --> void", pybind11::arg("newLength"));
+		cl.def("reserve", (void (mrpt::maps::CPointsMapXYZI::*)(size_t)) &mrpt::maps::CPointsMapXYZI::reserve, "from CPointsMap\n  @{ \n\nC++: mrpt::maps::CPointsMapXYZI::reserve(size_t) --> void", pybind11::arg("newLength"));
 		cl.def("resize", (void (mrpt::maps::CPointsMapXYZI::*)(size_t)) &mrpt::maps::CPointsMapXYZI::resize, "C++: mrpt::maps::CPointsMapXYZI::resize(size_t) --> void", pybind11::arg("newLength"));
 		cl.def("setSize", (void (mrpt::maps::CPointsMapXYZI::*)(size_t)) &mrpt::maps::CPointsMapXYZI::setSize, "C++: mrpt::maps::CPointsMapXYZI::setSize(size_t) --> void", pybind11::arg("newLength"));
-		cl.def("insertPointFast", [](mrpt::maps::CPointsMapXYZI &o, float const & a0, float const & a1) -> void { return o.insertPointFast(a0, a1); }, "", pybind11::arg("x"), pybind11::arg("y"));
-		cl.def("insertPointFast", (void (mrpt::maps::CPointsMapXYZI::*)(float, float, float)) &mrpt::maps::CPointsMapXYZI::insertPointFast, "The virtual method for  *without* calling\n mark_as_modified()   \n\nC++: mrpt::maps::CPointsMapXYZI::insertPointFast(float, float, float) --> void", pybind11::arg("x"), pybind11::arg("y"), pybind11::arg("z"));
 		cl.def("loadFromKittiVelodyneFile", (bool (mrpt::maps::CPointsMapXYZI::*)(const std::string &)) &mrpt::maps::CPointsMapXYZI::loadFromKittiVelodyneFile, "Loads from a Kitti dataset Velodyne scan binary file.\n The file can be gz compressed (only enabled if the filename ends in \".gz\"\n to prevent spurious false autodetection of gzip files).\n \n\n true on success \n\nC++: mrpt::maps::CPointsMapXYZI::loadFromKittiVelodyneFile(const std::string &) --> bool", pybind11::arg("filename"));
 		cl.def("saveToKittiVelodyneFile", (bool (mrpt::maps::CPointsMapXYZI::*)(const std::string &) const) &mrpt::maps::CPointsMapXYZI::saveToKittiVelodyneFile, "C++: mrpt::maps::CPointsMapXYZI::saveToKittiVelodyneFile(const std::string &) const --> bool", pybind11::arg("filename"));
-		cl.def("saveXYZI_to_text_file", (bool (mrpt::maps::CPointsMapXYZI::*)(const std::string &) const) &mrpt::maps::CPointsMapXYZI::saveXYZI_to_text_file, "Save to a text file. In each line contains X Y Z (meters) I (intensity)\n Returns false if any error occured, true elsewere.\n\nC++: mrpt::maps::CPointsMapXYZI::saveXYZI_to_text_file(const std::string &) const --> bool", pybind11::arg("file"));
-		cl.def("loadXYZI_from_text_file", (bool (mrpt::maps::CPointsMapXYZI::*)(const std::string &)) &mrpt::maps::CPointsMapXYZI::loadXYZI_from_text_file, "Loads from a text file, each line having \"X Y Z I\", I in [0,1].\n Returns false if any error occured, true elsewere. \n\nC++: mrpt::maps::CPointsMapXYZI::loadXYZI_from_text_file(const std::string &) --> bool", pybind11::arg("file"));
+		cl.def("saveXYZI_to_text_file", (bool (mrpt::maps::CPointsMapXYZI::*)(const std::string &) const) &mrpt::maps::CPointsMapXYZI::saveXYZI_to_text_file, "Save to a text file. In each line contains X Y Z (meters) I (intensity)\n Returns false if any error occurred, true elsewere.\n\nC++: mrpt::maps::CPointsMapXYZI::saveXYZI_to_text_file(const std::string &) const --> bool", pybind11::arg("file"));
+		cl.def("loadXYZI_from_text_file", (bool (mrpt::maps::CPointsMapXYZI::*)(const std::string &)) &mrpt::maps::CPointsMapXYZI::loadXYZI_from_text_file, "Loads from a text file, each line having \"X Y Z I\", I in [0,1].\n Returns false if any error occurred, true elsewere. \n\nC++: mrpt::maps::CPointsMapXYZI::loadXYZI_from_text_file(const std::string &) --> bool", pybind11::arg("file"));
 		cl.def("setPointRGB", (void (mrpt::maps::CPointsMapXYZI::*)(size_t, float, float, float, float, float, float)) &mrpt::maps::CPointsMapXYZI::setPointRGB, "Changes a given point from map. First index is 0.\n \n\n Throws std::exception on index out of bound.\n\nC++: mrpt::maps::CPointsMapXYZI::setPointRGB(size_t, float, float, float, float, float, float) --> void", pybind11::arg("index"), pybind11::arg("x"), pybind11::arg("y"), pybind11::arg("z"), pybind11::arg("R_intensity"), pybind11::arg("G_ignored"), pybind11::arg("B_ignored"));
 		cl.def("insertPointRGB", (void (mrpt::maps::CPointsMapXYZI::*)(float, float, float, float, float, float)) &mrpt::maps::CPointsMapXYZI::insertPointRGB, "Adds a new point given its coordinates and color (colors range is [0,1])\n\nC++: mrpt::maps::CPointsMapXYZI::insertPointRGB(float, float, float, float, float, float) --> void", pybind11::arg("x"), pybind11::arg("y"), pybind11::arg("z"), pybind11::arg("R_intensity"), pybind11::arg("G_ignored"), pybind11::arg("B_ignored"));
 		cl.def("setPointIntensity", (void (mrpt::maps::CPointsMapXYZI::*)(size_t, float)) &mrpt::maps::CPointsMapXYZI::setPointIntensity, "Changes the intensity of a given point from the map. First index is 0.\n \n\n Throws std::exception on index out of bound.\n\nC++: mrpt::maps::CPointsMapXYZI::setPointIntensity(size_t, float) --> void", pybind11::arg("index"), pybind11::arg("intensity"));
-		cl.def("setPointColor_fast", (void (mrpt::maps::CPointsMapXYZI::*)(size_t, float, float, float)) &mrpt::maps::CPointsMapXYZI::setPointColor_fast, "Like  but without checking for out-of-index erors \n\nC++: mrpt::maps::CPointsMapXYZI::setPointColor_fast(size_t, float, float, float) --> void", pybind11::arg("index"), pybind11::arg("R"), pybind11::arg("G"), pybind11::arg("B"));
+		cl.def("setPointColor_fast", (void (mrpt::maps::CPointsMapXYZI::*)(size_t, float, float, float)) &mrpt::maps::CPointsMapXYZI::setPointColor_fast, "Like  but without checking for out-of-index errors \n\nC++: mrpt::maps::CPointsMapXYZI::setPointColor_fast(size_t, float, float, float) --> void", pybind11::arg("index"), pybind11::arg("R"), pybind11::arg("G"), pybind11::arg("B"));
 		cl.def("getPointRGB", (void (mrpt::maps::CPointsMapXYZI::*)(size_t, float &, float &, float &, float &, float &, float &) const) &mrpt::maps::CPointsMapXYZI::getPointRGB, "Retrieves a point and its color (colors range is [0,1])\n\nC++: mrpt::maps::CPointsMapXYZI::getPointRGB(size_t, float &, float &, float &, float &, float &, float &) const --> void", pybind11::arg("index"), pybind11::arg("x"), pybind11::arg("y"), pybind11::arg("z"), pybind11::arg("R_intensity"), pybind11::arg("G_intensity"), pybind11::arg("B_intensity"));
 		cl.def("getPointIntensity", (float (mrpt::maps::CPointsMapXYZI::*)(size_t) const) &mrpt::maps::CPointsMapXYZI::getPointIntensity, "Retrieves a point intensity (range [0,1]) \n\nC++: mrpt::maps::CPointsMapXYZI::getPointIntensity(size_t) const --> float", pybind11::arg("index"));
-		cl.def("getPointIntensity_fast", (float (mrpt::maps::CPointsMapXYZI::*)(size_t) const) &mrpt::maps::CPointsMapXYZI::getPointIntensity_fast, "Like  but without checking for out-of-index erors \n\nC++: mrpt::maps::CPointsMapXYZI::getPointIntensity_fast(size_t) const --> float", pybind11::arg("index"));
+		cl.def("getPointIntensity_fast", (float (mrpt::maps::CPointsMapXYZI::*)(size_t) const) &mrpt::maps::CPointsMapXYZI::getPointIntensity_fast, "Like  but without checking for out-of-index errors \n\nC++: mrpt::maps::CPointsMapXYZI::getPointIntensity_fast(size_t) const --> float", pybind11::arg("index"));
 		cl.def("hasColorPoints", (bool (mrpt::maps::CPointsMapXYZI::*)() const) &mrpt::maps::CPointsMapXYZI::hasColorPoints, "Returns true if the point map has a color field for each point \n\nC++: mrpt::maps::CPointsMapXYZI::hasColorPoints() const --> bool");
 		cl.def("getVisualizationInto", (void (mrpt::maps::CPointsMapXYZI::*)(class mrpt::opengl::CSetOfObjects &) const) &mrpt::maps::CPointsMapXYZI::getVisualizationInto, "Override of the default 3D scene builder to account for the individual\n points' color.\n\nC++: mrpt::maps::CPointsMapXYZI::getVisualizationInto(class mrpt::opengl::CSetOfObjects &) const --> void", pybind11::arg("outObj"));
-		cl.def("insertPointField_Intensity", (void (mrpt::maps::CPointsMapXYZI::*)(float)) &mrpt::maps::CPointsMapXYZI::insertPointField_Intensity, "C++: mrpt::maps::CPointsMapXYZI::insertPointField_Intensity(float) --> void", pybind11::arg("i"));
 		cl.def("saveMetricMapRepresentationToFile", (void (mrpt::maps::CPointsMapXYZI::*)(const std::string &) const) &mrpt::maps::CPointsMapXYZI::saveMetricMapRepresentationToFile, "clang-format on\n\nC++: mrpt::maps::CPointsMapXYZI::saveMetricMapRepresentationToFile(const std::string &) const --> void", pybind11::arg("filNamePrefix"));
 
-		{ // mrpt::maps::CPointsMapXYZI::TMapDefinitionBase file: line:80
+		{ // mrpt::maps::CPointsMapXYZI::TMapDefinitionBase file: line:74
 			auto & enclosing_class = cl;
 			pybind11::class_<mrpt::maps::CPointsMapXYZI::TMapDefinitionBase, std::shared_ptr<mrpt::maps::CPointsMapXYZI::TMapDefinitionBase>> cl(enclosing_class, "TMapDefinitionBase", "");
 		}
 
-		{ // mrpt::maps::CPointsMapXYZI::TMapDefinition file: line:85
+		{ // mrpt::maps::CPointsMapXYZI::TMapDefinition file: line:78
 			auto & enclosing_class = cl;
 			pybind11::class_<mrpt::maps::CPointsMapXYZI::TMapDefinition, std::shared_ptr<mrpt::maps::CPointsMapXYZI::TMapDefinition>, PyCallBack_mrpt_maps_CPointsMapXYZI_TMapDefinition, mrpt::maps::CPointsMapXYZI::TMapDefinitionBase> cl(enclosing_class, "TMapDefinition", "");
 			cl.def( pybind11::init( [](){ return new mrpt::maps::CPointsMapXYZI::TMapDefinition(); }, [](){ return new PyCallBack_mrpt_maps_CPointsMapXYZI_TMapDefinition(); } ) );
