@@ -9,7 +9,6 @@
 #include <mrpt/opengl/CSetOfObjects.h>
 #include <mrpt/rtti/CObject.h>
 #include <mrpt/serialization/CArchive.h>
-#include <mrpt/serialization/CMessage.h>
 #include <mrpt/serialization/CSerializable.h>
 #include <mrpt/system/COutputLogger.h>
 #include <mrpt/typemeta/static_string.h>
@@ -103,7 +102,7 @@ struct PyCallBack_mrpt_nav_CLogFileRecord : public mrpt::nav::CLogFileRecord {
 	}
 };
 
-// mrpt::nav::CMultiObjectiveMotionOptimizerBase::TParamsBase file:mrpt/nav/reactive/CMultiObjectiveMotionOptimizerBase.h line:59
+// mrpt::nav::CMultiObjectiveMotionOptimizerBase::TParamsBase file:mrpt/nav/reactive/CMultiObjectiveMotionOptimizerBase.h line:56
 struct PyCallBack_mrpt_nav_CMultiObjectiveMotionOptimizerBase_TParamsBase : public mrpt::nav::CMultiObjectiveMotionOptimizerBase::TParamsBase {
 	using mrpt::nav::CMultiObjectiveMotionOptimizerBase::TParamsBase::TParamsBase;
 
@@ -142,7 +141,6 @@ void bind_mrpt_nav_reactive_CLogFileRecord(std::function< pybind11::module &(std
 		cl.def( pybind11::init( [](){ return new mrpt::nav::CLogFileRecord(); }, [](){ return new PyCallBack_mrpt_nav_CLogFileRecord(); } ) );
 		cl.def( pybind11::init( [](PyCallBack_mrpt_nav_CLogFileRecord const &o){ return new PyCallBack_mrpt_nav_CLogFileRecord(o); } ) );
 		cl.def( pybind11::init( [](mrpt::nav::CLogFileRecord const &o){ return new mrpt::nav::CLogFileRecord(o); } ) );
-		cl.def_readwrite("navDynState", &mrpt::nav::CLogFileRecord::navDynState);
 		cl.def_readwrite("nPTGs", &mrpt::nav::CLogFileRecord::nPTGs);
 		cl.def_readwrite("infoPerPTG", &mrpt::nav::CLogFileRecord::infoPerPTG);
 		cl.def_readwrite("nSelectedPTG", &mrpt::nav::CLogFileRecord::nSelectedPTG);
@@ -167,7 +165,6 @@ void bind_mrpt_nav_reactive_CLogFileRecord(std::function< pybind11::module &(std
 		cl.def_readwrite("ptg_last_k_NOP", &mrpt::nav::CLogFileRecord::ptg_last_k_NOP);
 		cl.def_readwrite("rel_cur_pose_wrt_last_vel_cmd_NOP", &mrpt::nav::CLogFileRecord::rel_cur_pose_wrt_last_vel_cmd_NOP);
 		cl.def_readwrite("rel_pose_PTG_origin_wrt_sense_NOP", &mrpt::nav::CLogFileRecord::rel_pose_PTG_origin_wrt_sense_NOP);
-		cl.def_readwrite("ptg_last_navDynState", &mrpt::nav::CLogFileRecord::ptg_last_navDynState);
 		cl.def_readwrite("visuals", &mrpt::nav::CLogFileRecord::visuals);
 		cl.def_static("GetRuntimeClassIdStatic", (const struct mrpt::rtti::TRuntimeClassId & (*)()) &mrpt::nav::CLogFileRecord::GetRuntimeClassIdStatic, "C++: mrpt::nav::CLogFileRecord::GetRuntimeClassIdStatic() --> const struct mrpt::rtti::TRuntimeClassId &", pybind11::return_value_policy::automatic);
 		cl.def("GetRuntimeClass", (const struct mrpt::rtti::TRuntimeClassId * (mrpt::nav::CLogFileRecord::*)() const) &mrpt::nav::CLogFileRecord::GetRuntimeClass, "C++: mrpt::nav::CLogFileRecord::GetRuntimeClass() const --> const struct mrpt::rtti::TRuntimeClassId *", pybind11::return_value_policy::automatic);
@@ -193,6 +190,8 @@ void bind_mrpt_nav_reactive_CLogFileRecord(std::function< pybind11::module &(std
 			cl.def_readwrite("HLFR", &mrpt::nav::CLogFileRecord::TInfoPerPTG::HLFR);
 			cl.def_readwrite("ptg", &mrpt::nav::CLogFileRecord::TInfoPerPTG::ptg);
 			cl.def_readwrite("clearance", &mrpt::nav::CLogFileRecord::TInfoPerPTG::clearance);
+			cl.def_readwrite("dynState", &mrpt::nav::CLogFileRecord::TInfoPerPTG::dynState);
+			cl.def_readwrite("lastDynState", &mrpt::nav::CLogFileRecord::TInfoPerPTG::lastDynState);
 			cl.def("assign", (struct mrpt::nav::CLogFileRecord::TInfoPerPTG & (mrpt::nav::CLogFileRecord::TInfoPerPTG::*)(const struct mrpt::nav::CLogFileRecord::TInfoPerPTG &)) &mrpt::nav::CLogFileRecord::TInfoPerPTG::operator=, "C++: mrpt::nav::CLogFileRecord::TInfoPerPTG::operator=(const struct mrpt::nav::CLogFileRecord::TInfoPerPTG &) --> struct mrpt::nav::CLogFileRecord::TInfoPerPTG &", pybind11::return_value_policy::automatic, pybind11::arg(""));
 		}
 
@@ -217,7 +216,7 @@ void bind_mrpt_nav_reactive_CLogFileRecord(std::function< pybind11::module &(std
 		cl.def("saveConfigFile", (void (mrpt::nav::CMultiObjectiveMotionOptimizerBase::*)(class mrpt::config::CConfigFileBase &) const) &mrpt::nav::CMultiObjectiveMotionOptimizerBase::saveConfigFile, "C++: mrpt::nav::CMultiObjectiveMotionOptimizerBase::saveConfigFile(class mrpt::config::CConfigFileBase &) const --> void", pybind11::arg("c"));
 		cl.def("clear", (void (mrpt::nav::CMultiObjectiveMotionOptimizerBase::*)()) &mrpt::nav::CMultiObjectiveMotionOptimizerBase::clear, "Resets the object state; use if the parameters change, so they are\n re-read and applied. \n\nC++: mrpt::nav::CMultiObjectiveMotionOptimizerBase::clear() --> void");
 
-		{ // mrpt::nav::CMultiObjectiveMotionOptimizerBase::TResultInfo file:mrpt/nav/reactive/CMultiObjectiveMotionOptimizerBase.h line:32
+		{ // mrpt::nav::CMultiObjectiveMotionOptimizerBase::TResultInfo file:mrpt/nav/reactive/CMultiObjectiveMotionOptimizerBase.h line:31
 			auto & enclosing_class = cl;
 			pybind11::class_<mrpt::nav::CMultiObjectiveMotionOptimizerBase::TResultInfo, std::shared_ptr<mrpt::nav::CMultiObjectiveMotionOptimizerBase::TResultInfo>> cl(enclosing_class, "TResultInfo", "");
 			cl.def( pybind11::init( [](){ return new mrpt::nav::CMultiObjectiveMotionOptimizerBase::TResultInfo(); } ) );
@@ -228,7 +227,7 @@ void bind_mrpt_nav_reactive_CLogFileRecord(std::function< pybind11::module &(std
 			cl.def("assign", (struct mrpt::nav::CMultiObjectiveMotionOptimizerBase::TResultInfo & (mrpt::nav::CMultiObjectiveMotionOptimizerBase::TResultInfo::*)(const struct mrpt::nav::CMultiObjectiveMotionOptimizerBase::TResultInfo &)) &mrpt::nav::CMultiObjectiveMotionOptimizerBase::TResultInfo::operator=, "C++: mrpt::nav::CMultiObjectiveMotionOptimizerBase::TResultInfo::operator=(const struct mrpt::nav::CMultiObjectiveMotionOptimizerBase::TResultInfo &) --> struct mrpt::nav::CMultiObjectiveMotionOptimizerBase::TResultInfo &", pybind11::return_value_policy::automatic, pybind11::arg(""));
 		}
 
-		{ // mrpt::nav::CMultiObjectiveMotionOptimizerBase::TParamsBase file:mrpt/nav/reactive/CMultiObjectiveMotionOptimizerBase.h line:59
+		{ // mrpt::nav::CMultiObjectiveMotionOptimizerBase::TParamsBase file:mrpt/nav/reactive/CMultiObjectiveMotionOptimizerBase.h line:56
 			auto & enclosing_class = cl;
 			pybind11::class_<mrpt::nav::CMultiObjectiveMotionOptimizerBase::TParamsBase, std::shared_ptr<mrpt::nav::CMultiObjectiveMotionOptimizerBase::TParamsBase>, PyCallBack_mrpt_nav_CMultiObjectiveMotionOptimizerBase_TParamsBase, mrpt::config::CLoadableOptions> cl(enclosing_class, "TParamsBase", "Common params for all children ");
 			cl.def( pybind11::init( [](){ return new mrpt::nav::CMultiObjectiveMotionOptimizerBase::TParamsBase(); }, [](){ return new PyCallBack_mrpt_nav_CMultiObjectiveMotionOptimizerBase_TParamsBase(); } ) );
@@ -243,7 +242,7 @@ void bind_mrpt_nav_reactive_CLogFileRecord(std::function< pybind11::module &(std
 		}
 
 	}
-	{ // mrpt::nav::TWaypoint file:mrpt/nav/reactive/TWaypoint.h line:26
+	{ // mrpt::nav::TWaypoint file:mrpt/nav/reactive/TWaypoint.h line:27
 		pybind11::class_<mrpt::nav::TWaypoint, std::shared_ptr<mrpt::nav::TWaypoint>> cl(M("mrpt::nav"), "TWaypoint", "A single waypoint within TWaypointSequence. ");
 		cl.def( pybind11::init( [](){ return new mrpt::nav::TWaypoint(); } ) );
 		cl.def( pybind11::init( [](mrpt::nav::TWaypoint const &o){ return new mrpt::nav::TWaypoint(o); } ) );
