@@ -13,7 +13,6 @@
 #include <mrpt/poses/CPoseOrPoint.h>
 #include <mrpt/rtti/CObject.h>
 #include <mrpt/serialization/CArchive.h>
-#include <mrpt/serialization/CMessage.h>
 #include <mrpt/serialization/CSerializable.h>
 #include <mrpt/typemeta/static_string.h>
 #include <ostream>
@@ -114,7 +113,7 @@ void bind_mrpt_obs_CActionRobotMovement2D(std::function< pybind11::module &(std:
 		cl.def( pybind11::init( [](PyCallBack_mrpt_obs_CActionRobotMovement2D const &o){ return new PyCallBack_mrpt_obs_CActionRobotMovement2D(o); } ) );
 		cl.def( pybind11::init( [](mrpt::obs::CActionRobotMovement2D const &o){ return new mrpt::obs::CActionRobotMovement2D(o); } ) );
 
-		pybind11::enum_<mrpt::obs::CActionRobotMovement2D::TEstimationMethod>(cl, "TEstimationMethod", pybind11::arithmetic(), "A list of posible ways for estimating the content of a\n CActionRobotMovement2D object.")
+		pybind11::enum_<mrpt::obs::CActionRobotMovement2D::TEstimationMethod>(cl, "TEstimationMethod", pybind11::arithmetic(), "A list of possible ways for estimating the content of a\n CActionRobotMovement2D object.")
 			.value("emOdometry", mrpt::obs::CActionRobotMovement2D::emOdometry)
 			.value("emScan2DMatching", mrpt::obs::CActionRobotMovement2D::emScan2DMatching)
 			.export_values();
@@ -173,7 +172,7 @@ void bind_mrpt_obs_CActionRobotMovement2D(std::function< pybind11::module &(std:
 				cl.def("assign", (struct mrpt::obs::CActionRobotMovement2D::TMotionModelOptions::TOptions_GaussianModel & (mrpt::obs::CActionRobotMovement2D::TMotionModelOptions::TOptions_GaussianModel::*)(const struct mrpt::obs::CActionRobotMovement2D::TMotionModelOptions::TOptions_GaussianModel &)) &mrpt::obs::CActionRobotMovement2D::TMotionModelOptions::TOptions_GaussianModel::operator=, "C++: mrpt::obs::CActionRobotMovement2D::TMotionModelOptions::TOptions_GaussianModel::operator=(const struct mrpt::obs::CActionRobotMovement2D::TMotionModelOptions::TOptions_GaussianModel &) --> struct mrpt::obs::CActionRobotMovement2D::TMotionModelOptions::TOptions_GaussianModel &", pybind11::return_value_policy::automatic, pybind11::arg(""));
 			}
 
-			{ // mrpt::obs::CActionRobotMovement2D::TMotionModelOptions::TOptions_ThrunModel file:mrpt/obs/CActionRobotMovement2D.h line:128
+			{ // mrpt::obs::CActionRobotMovement2D::TMotionModelOptions::TOptions_ThrunModel file:mrpt/obs/CActionRobotMovement2D.h line:122
 				auto & enclosing_class = cl;
 				pybind11::class_<mrpt::obs::CActionRobotMovement2D::TMotionModelOptions::TOptions_ThrunModel, std::shared_ptr<mrpt::obs::CActionRobotMovement2D::TMotionModelOptions::TOptions_ThrunModel>> cl(enclosing_class, "TOptions_ThrunModel", "Options for the Thrun's model, which generates a CPosePDFParticles\n object in poseChange using a MonteCarlo simulation.\n See docs in:\n https://docs.mrpt.org/reference/latest/tutorial-motion-models.html");
 				cl.def( pybind11::init( [](){ return new mrpt::obs::CActionRobotMovement2D::TMotionModelOptions::TOptions_ThrunModel(); } ) );
