@@ -23,7 +23,6 @@
 #include <mrpt/poses/CPoseOrPoint.h>
 #include <mrpt/rtti/CObject.h>
 #include <mrpt/serialization/CArchive.h>
-#include <mrpt/serialization/CMessage.h>
 #include <mrpt/serialization/CSerializable.h>
 #include <mrpt/typemeta/static_string.h>
 #include <optional>
@@ -254,11 +253,11 @@ void bind_mrpt_obs_CObservation(std::function< pybind11::module &(std::string co
 		cl.def("setSensorPose", (void (mrpt::obs::CObservation::*)(const class mrpt::poses::CPose3D &)) &mrpt::obs::CObservation::setSensorPose, "A general method to change the sensor pose on the robot.\n  Note that most sensors will use the full (6D) CPose3D, but see the\n derived classes for more details or special cases.\n \n\n getSensorPose\n\nC++: mrpt::obs::CObservation::setSensorPose(const class mrpt::poses::CPose3D &) --> void", pybind11::arg("newSensorPose"));
 		cl.def("setSensorPose", (void (mrpt::obs::CObservation::*)(const struct mrpt::math::TPose3D &)) &mrpt::obs::CObservation::setSensorPose, "A general method to change the sensor pose on the robot.\n  Note that most sensors will use the full (6D) CPose3D, but see the\n derived classes for more details or special cases.\n \n\n getSensorPose\n\nC++: mrpt::obs::CObservation::setSensorPose(const struct mrpt::math::TPose3D &) --> void", pybind11::arg("newSensorPose"));
 		cl.def("asString", (std::string (mrpt::obs::CObservation::*)() const) &mrpt::obs::CObservation::asString, "Return by value version of getDescriptionAsText(std::ostream&).\n\nC++: mrpt::obs::CObservation::asString() const --> std::string");
-		cl.def("exportTxtSupported", (bool (mrpt::obs::CObservation::*)() const) &mrpt::obs::CObservation::exportTxtSupported, "		@{ \n\n Must return true if the class is exportable to TXT/CSV files, in which\n case the other virtual methods in this group must be redefined too.\n\nC++: mrpt::obs::CObservation::exportTxtSupported() const --> bool");
+		cl.def("exportTxtSupported", (bool (mrpt::obs::CObservation::*)() const) &mrpt::obs::CObservation::exportTxtSupported, "@{ \n\n Must return true if the class is exportable to TXT/CSV files, in which\n case the other virtual methods in this group must be redefined too.\n\nC++: mrpt::obs::CObservation::exportTxtSupported() const --> bool");
 		cl.def("exportTxtHeader", (std::string (mrpt::obs::CObservation::*)() const) &mrpt::obs::CObservation::exportTxtHeader, "Returns the description of the data columns. Timestamp is automatically\n included as the first column, do not list it. See example implementations\n if interested in enabling this in custom CObservation classes.\n Do not include newlines.\n\nC++: mrpt::obs::CObservation::exportTxtHeader() const --> std::string");
 		cl.def("exportTxtDataRow", (std::string (mrpt::obs::CObservation::*)() const) &mrpt::obs::CObservation::exportTxtDataRow, "Returns one row of data with the data stored in this particular object.\n Do not include newlines. \n\nC++: mrpt::obs::CObservation::exportTxtDataRow() const --> std::string");
 		cl.def("load", (void (mrpt::obs::CObservation::*)() const) &mrpt::obs::CObservation::load, "Makes sure all images and other fields which may be externally stored\n are loaded in memory.\n  Note that for all CImages, calling load() is not required since the\n images will be automatically loaded upon first access, so load()\n shouldn't be needed to be called in normal cases by the user.\n  If all the data were alredy loaded or this object has no externally\n stored data fields, calling this method has no effects.\n \n\n unload\n\nC++: mrpt::obs::CObservation::load() const --> void");
-		cl.def("unload", (void (mrpt::obs::CObservation::*)() const) &mrpt::obs::CObservation::unload, "Unload all images, for the case they being delayed-load images stored in\n external files (othewise, has no effect).\n \n\n load\n\nC++: mrpt::obs::CObservation::unload() const --> void");
+		cl.def("unload", (void (mrpt::obs::CObservation::*)() const) &mrpt::obs::CObservation::unload, "Unload all images, for the case they being delayed-load images stored in\n external files (otherwise, has no effect).\n \n\n load\n\nC++: mrpt::obs::CObservation::unload() const --> void");
 		cl.def("assign", (class mrpt::obs::CObservation & (mrpt::obs::CObservation::*)(const class mrpt::obs::CObservation &)) &mrpt::obs::CObservation::operator=, "C++: mrpt::obs::CObservation::operator=(const class mrpt::obs::CObservation &) --> class mrpt::obs::CObservation &", pybind11::return_value_policy::automatic, pybind11::arg(""));
 	}
 }
