@@ -3,7 +3,6 @@
 #include <mrpt/hwdrivers/CVelodyneScanner.h>
 #include <mrpt/maps/CColouredPointsMap.h>
 #include <mrpt/maps/CHeightGridMap2D.h>
-#include <mrpt/maps/COccupancyGridMap2D.h>
 #include <mrpt/maps/CRandomFieldGridMap2D.h>
 #include <mrpt/typemeta/TEnumType.h>
 #include <sstream> // __str__
@@ -24,6 +23,17 @@
 
 void bind_mrpt_typemeta_TEnumType_3(std::function< pybind11::module &(std::string const &namespace_) > &M)
 {
+	{ // mrpt::typemeta::internal::bimap file:mrpt/typemeta/TEnumType.h line:22
+		pybind11::class_<mrpt::typemeta::internal::bimap<mrpt::hwdrivers::CVelodyneScanner::model_t,std::string>, std::shared_ptr<mrpt::typemeta::internal::bimap<mrpt::hwdrivers::CVelodyneScanner::model_t,std::string>>> cl(M("mrpt::typemeta::internal"), "bimap_mrpt_hwdrivers_CVelodyneScanner_model_t_std_string_t", "");
+		cl.def( pybind11::init( [](){ return new mrpt::typemeta::internal::bimap<mrpt::hwdrivers::CVelodyneScanner::model_t,std::string>(); } ) );
+		cl.def( pybind11::init( [](mrpt::typemeta::internal::bimap<mrpt::hwdrivers::CVelodyneScanner::model_t,std::string> const &o){ return new mrpt::typemeta::internal::bimap<mrpt::hwdrivers::CVelodyneScanner::model_t,std::string>(o); } ) );
+		cl.def_readwrite("m_k2v", &mrpt::typemeta::internal::bimap<mrpt::hwdrivers::CVelodyneScanner::model_t,std::string>::m_k2v);
+		cl.def_readwrite("m_v2k", &mrpt::typemeta::internal::bimap<mrpt::hwdrivers::CVelodyneScanner::model_t,std::string>::m_v2k);
+		cl.def("direct", (bool (mrpt::typemeta::internal::bimap<mrpt::hwdrivers::CVelodyneScanner::model_t,std::string>::*)(const enum mrpt::hwdrivers::CVelodyneScanner::model_t &, std::string &) const) &mrpt::typemeta::internal::bimap<mrpt::hwdrivers::CVelodyneScanner::model_t, std::string>::direct, "C++: mrpt::typemeta::internal::bimap<mrpt::hwdrivers::CVelodyneScanner::model_t, std::string>::direct(const enum mrpt::hwdrivers::CVelodyneScanner::model_t &, std::string &) const --> bool", pybind11::arg("k"), pybind11::arg("out_v"));
+		cl.def("inverse", (bool (mrpt::typemeta::internal::bimap<mrpt::hwdrivers::CVelodyneScanner::model_t,std::string>::*)(const std::string &, enum mrpt::hwdrivers::CVelodyneScanner::model_t &) const) &mrpt::typemeta::internal::bimap<mrpt::hwdrivers::CVelodyneScanner::model_t, std::string>::inverse, "C++: mrpt::typemeta::internal::bimap<mrpt::hwdrivers::CVelodyneScanner::model_t, std::string>::inverse(const std::string &, enum mrpt::hwdrivers::CVelodyneScanner::model_t &) const --> bool", pybind11::arg("v"), pybind11::arg("out_k"));
+		cl.def("insert", (void (mrpt::typemeta::internal::bimap<mrpt::hwdrivers::CVelodyneScanner::model_t,std::string>::*)(const enum mrpt::hwdrivers::CVelodyneScanner::model_t &, const std::string &)) &mrpt::typemeta::internal::bimap<mrpt::hwdrivers::CVelodyneScanner::model_t, std::string>::insert, "C++: mrpt::typemeta::internal::bimap<mrpt::hwdrivers::CVelodyneScanner::model_t, std::string>::insert(const enum mrpt::hwdrivers::CVelodyneScanner::model_t &, const std::string &) --> void", pybind11::arg("k"), pybind11::arg("v"));
+		cl.def("assign", (struct mrpt::typemeta::internal::bimap<enum mrpt::hwdrivers::CVelodyneScanner::model_t, std::string > & (mrpt::typemeta::internal::bimap<mrpt::hwdrivers::CVelodyneScanner::model_t,std::string>::*)(const struct mrpt::typemeta::internal::bimap<enum mrpt::hwdrivers::CVelodyneScanner::model_t, std::string > &)) &mrpt::typemeta::internal::bimap<mrpt::hwdrivers::CVelodyneScanner::model_t, std::string>::operator=, "C++: mrpt::typemeta::internal::bimap<mrpt::hwdrivers::CVelodyneScanner::model_t, std::string>::operator=(const struct mrpt::typemeta::internal::bimap<enum mrpt::hwdrivers::CVelodyneScanner::model_t, std::string > &) --> struct mrpt::typemeta::internal::bimap<enum mrpt::hwdrivers::CVelodyneScanner::model_t, std::string > &", pybind11::return_value_policy::automatic, pybind11::arg(""));
+	}
 	{ // mrpt::typemeta::internal::bimap file:mrpt/typemeta/TEnumType.h line:22
 		pybind11::class_<mrpt::typemeta::internal::bimap<mrpt::hwdrivers::CVelodyneScanner::return_type_t,std::string>, std::shared_ptr<mrpt::typemeta::internal::bimap<mrpt::hwdrivers::CVelodyneScanner::return_type_t,std::string>>> cl(M("mrpt::typemeta::internal"), "bimap_mrpt_hwdrivers_CVelodyneScanner_return_type_t_std_string_t", "");
 		cl.def( pybind11::init( [](){ return new mrpt::typemeta::internal::bimap<mrpt::hwdrivers::CVelodyneScanner::return_type_t,std::string>(); } ) );
@@ -68,15 +78,4 @@ void bind_mrpt_typemeta_TEnumType_3(std::function< pybind11::module &(std::strin
 		cl.def("insert", (void (mrpt::typemeta::internal::bimap<mrpt::maps::CHeightGridMap2D::TMapRepresentation,std::string>::*)(const enum mrpt::maps::CHeightGridMap2D::TMapRepresentation &, const std::string &)) &mrpt::typemeta::internal::bimap<mrpt::maps::CHeightGridMap2D::TMapRepresentation, std::string>::insert, "C++: mrpt::typemeta::internal::bimap<mrpt::maps::CHeightGridMap2D::TMapRepresentation, std::string>::insert(const enum mrpt::maps::CHeightGridMap2D::TMapRepresentation &, const std::string &) --> void", pybind11::arg("k"), pybind11::arg("v"));
 		cl.def("assign", (struct mrpt::typemeta::internal::bimap<enum mrpt::maps::CHeightGridMap2D::TMapRepresentation, std::string > & (mrpt::typemeta::internal::bimap<mrpt::maps::CHeightGridMap2D::TMapRepresentation,std::string>::*)(const struct mrpt::typemeta::internal::bimap<enum mrpt::maps::CHeightGridMap2D::TMapRepresentation, std::string > &)) &mrpt::typemeta::internal::bimap<mrpt::maps::CHeightGridMap2D::TMapRepresentation, std::string>::operator=, "C++: mrpt::typemeta::internal::bimap<mrpt::maps::CHeightGridMap2D::TMapRepresentation, std::string>::operator=(const struct mrpt::typemeta::internal::bimap<enum mrpt::maps::CHeightGridMap2D::TMapRepresentation, std::string > &) --> struct mrpt::typemeta::internal::bimap<enum mrpt::maps::CHeightGridMap2D::TMapRepresentation, std::string > &", pybind11::return_value_policy::automatic, pybind11::arg(""));
 	}
-	{ // mrpt::typemeta::internal::bimap file:mrpt/typemeta/TEnumType.h line:22
-		pybind11::class_<mrpt::typemeta::internal::bimap<mrpt::maps::COccupancyGridMap2D::TLikelihoodMethod,std::string>, std::shared_ptr<mrpt::typemeta::internal::bimap<mrpt::maps::COccupancyGridMap2D::TLikelihoodMethod,std::string>>> cl(M("mrpt::typemeta::internal"), "bimap_mrpt_maps_COccupancyGridMap2D_TLikelihoodMethod_std_string_t", "");
-		cl.def( pybind11::init( [](){ return new mrpt::typemeta::internal::bimap<mrpt::maps::COccupancyGridMap2D::TLikelihoodMethod,std::string>(); } ) );
-		cl.def( pybind11::init( [](mrpt::typemeta::internal::bimap<mrpt::maps::COccupancyGridMap2D::TLikelihoodMethod,std::string> const &o){ return new mrpt::typemeta::internal::bimap<mrpt::maps::COccupancyGridMap2D::TLikelihoodMethod,std::string>(o); } ) );
-		cl.def_readwrite("m_k2v", &mrpt::typemeta::internal::bimap<mrpt::maps::COccupancyGridMap2D::TLikelihoodMethod,std::string>::m_k2v);
-		cl.def_readwrite("m_v2k", &mrpt::typemeta::internal::bimap<mrpt::maps::COccupancyGridMap2D::TLikelihoodMethod,std::string>::m_v2k);
-		cl.def("direct", (bool (mrpt::typemeta::internal::bimap<mrpt::maps::COccupancyGridMap2D::TLikelihoodMethod,std::string>::*)(const enum mrpt::maps::COccupancyGridMap2D::TLikelihoodMethod &, std::string &) const) &mrpt::typemeta::internal::bimap<mrpt::maps::COccupancyGridMap2D::TLikelihoodMethod, std::string>::direct, "C++: mrpt::typemeta::internal::bimap<mrpt::maps::COccupancyGridMap2D::TLikelihoodMethod, std::string>::direct(const enum mrpt::maps::COccupancyGridMap2D::TLikelihoodMethod &, std::string &) const --> bool", pybind11::arg("k"), pybind11::arg("out_v"));
-		cl.def("inverse", (bool (mrpt::typemeta::internal::bimap<mrpt::maps::COccupancyGridMap2D::TLikelihoodMethod,std::string>::*)(const std::string &, enum mrpt::maps::COccupancyGridMap2D::TLikelihoodMethod &) const) &mrpt::typemeta::internal::bimap<mrpt::maps::COccupancyGridMap2D::TLikelihoodMethod, std::string>::inverse, "C++: mrpt::typemeta::internal::bimap<mrpt::maps::COccupancyGridMap2D::TLikelihoodMethod, std::string>::inverse(const std::string &, enum mrpt::maps::COccupancyGridMap2D::TLikelihoodMethod &) const --> bool", pybind11::arg("v"), pybind11::arg("out_k"));
-		cl.def("insert", (void (mrpt::typemeta::internal::bimap<mrpt::maps::COccupancyGridMap2D::TLikelihoodMethod,std::string>::*)(const enum mrpt::maps::COccupancyGridMap2D::TLikelihoodMethod &, const std::string &)) &mrpt::typemeta::internal::bimap<mrpt::maps::COccupancyGridMap2D::TLikelihoodMethod, std::string>::insert, "C++: mrpt::typemeta::internal::bimap<mrpt::maps::COccupancyGridMap2D::TLikelihoodMethod, std::string>::insert(const enum mrpt::maps::COccupancyGridMap2D::TLikelihoodMethod &, const std::string &) --> void", pybind11::arg("k"), pybind11::arg("v"));
-		cl.def("assign", (struct mrpt::typemeta::internal::bimap<enum mrpt::maps::COccupancyGridMap2D::TLikelihoodMethod, std::string > & (mrpt::typemeta::internal::bimap<mrpt::maps::COccupancyGridMap2D::TLikelihoodMethod,std::string>::*)(const struct mrpt::typemeta::internal::bimap<enum mrpt::maps::COccupancyGridMap2D::TLikelihoodMethod, std::string > &)) &mrpt::typemeta::internal::bimap<mrpt::maps::COccupancyGridMap2D::TLikelihoodMethod, std::string>::operator=, "C++: mrpt::typemeta::internal::bimap<mrpt::maps::COccupancyGridMap2D::TLikelihoodMethod, std::string>::operator=(const struct mrpt::typemeta::internal::bimap<enum mrpt::maps::COccupancyGridMap2D::TLikelihoodMethod, std::string > &) --> struct mrpt::typemeta::internal::bimap<enum mrpt::maps::COccupancyGridMap2D::TLikelihoodMethod, std::string > &", pybind11::return_value_policy::automatic, pybind11::arg(""));
-	}
 }
