@@ -26,36 +26,37 @@ using namespace std;
  */
 int main(int argc, char** argv)
 {
-	try
-	{
-		string confFileName;
-		if (argc < 2) confFileName = string("./conf.ini");
-		else
-			confFileName = string(argv[1]);
+  try
+  {
+    string confFileName;
+    if (argc < 2)
+      confFileName = string("./conf.ini");
+    else
+      confFileName = string(argv[1]);
 
-		CPhidgetInterfaceKitProximitySensors ik;
-		string section("IK_1");
-		CConfigFile conf(confFileName);
-		ik.loadConfig(conf, section);
-		ik.initialize();
-		CObservationRange obs;
-		do
-		{
-			ik.doProcess();
-			ik.getObservation(obs);
-			for (size_t i = 0; i < obs.sensedData.size(); i++)
-			{
-				cout << obs.sensedData[i].sensedDistance << "\t";
-			}
-			cout << endl;
-			std::this_thread::sleep_for(10ms);
-		} while (!mrpt::system::os::kbhit());
+    CPhidgetInterfaceKitProximitySensors ik;
+    string section("IK_1");
+    CConfigFile conf(confFileName);
+    ik.loadConfig(conf, section);
+    ik.initialize();
+    CObservationRange obs;
+    do
+    {
+      ik.doProcess();
+      ik.getObservation(obs);
+      for (size_t i = 0; i < obs.sensedData.size(); i++)
+      {
+        cout << obs.sensedData[i].sensedDistance << "\t";
+      }
+      cout << endl;
+      std::this_thread::sleep_for(10ms);
+    } while (!mrpt::system::os::kbhit());
 
-		return 0;
-	}
-	catch (const std::exception& e)
-	{
-		std::cerr << e.what();
-		return 1;
-	}
+    return 0;
+  }
+  catch (const std::exception& e)
+  {
+    std::cerr << e.what();
+    return 1;
+  }
 }
